feast.types.FeatureRow_pb2 — Feast 0.3.2 documentation

# Source code for feast.types.FeatureRow_pb2

    # -*- coding: utf-8 -*-
    # Generated by the protocol buffer compiler.  DO NOT EDIT!
    # source: feast/types/FeatureRow.proto

    import sys
    _b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
    from google.protobuf import descriptor as _descriptor
    from google.protobuf import message as _message
    from google.protobuf import reflection as _reflection
    from google.protobuf import symbol_database as _symbol_database
    # @@protoc_insertion_point(imports)

    _sym_db = _symbol_database.Default()

    from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
    from feast.types import Field_pb2 as feast_dot_types_dot_Field__pb2

    DESCRIPTOR = _descriptor.FileDescriptor(
      name='feast/types/FeatureRow.proto',
      package='feast.types',
      syntax='proto3',
      serialized_options=_b('\n\013feast.typesB\017FeatureRowProtoZ0github.com/gojek/feast/sdk/go/protos/feast/types'),
      serialized_pb=_b('\n\x1c\x66\x65\x61st/types/FeatureRow.proto\x12\x0b\x66\x65\x61st.types\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17\x66\x65\x61st/types/Field.proto\"z\n\nFeatureRow\x12\"\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x12.feast.types.Field\x12\x33\n\x0f\x65vent_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x66\x65\x61ture_set\x18\x06 \x01(\tBP\n\x0b\x66\x65\x61st.typesB\x0f\x46\x65\x61tureRowProtoZ0github.com/gojek/feast/sdk/go/protos/feast/typesb\x06proto3')
      ,
      dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,feast_dot_types_dot_Field__pb2.DESCRIPTOR,])

    _FEATUREROW = _descriptor.Descriptor(
      name='FeatureRow',
      full_name='feast.types.FeatureRow',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      fields=[
        _descriptor.FieldDescriptor(
          name='fields', full_name='feast.types.FeatureRow.fields', index=0,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
          name='event_timestamp', full_name='feast.types.FeatureRow.event_timestamp', index=1,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
          name='feature_set', full_name='feast.types.FeatureRow.feature_set', index=2,
          number=6, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=_b("").decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=103,
      serialized_end=225,
    )

    _FEATUREROW.fields_by_name['fields'].message_type = feast_dot_types_dot_Field__pb2._FIELD
    _FEATUREROW.fields_by_name['event_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
    DESCRIPTOR.message_types_by_name['FeatureRow'] = _FEATUREROW
    _sym_db.RegisterFileDescriptor(DESCRIPTOR)

    FeatureRow = _reflection.GeneratedProtocolMessageType('FeatureRow', (_message.Message,), {
      'DESCRIPTOR' : _FEATUREROW,
      '__module__' : 'feast.types.FeatureRow_pb2'
      # @@protoc_insertion_point(class_scope:feast.types.FeatureRow)
      })
    _sym_db.RegisterMessage(FeatureRow)

    DESCRIPTOR._options = None
    # @@protoc_insertion_point(module_scope)